#[non_exhaustive]pub struct EncodeOptions {
pub max_z_error: f64,
pub micro_block_size: u32,
pub no_data_value: Option<f64>,
}Expand description
Controls the accuracy and representation of a newly encoded LERC blob.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_z_error: f64Maximum absolute reconstruction error for valid samples.
micro_block_size: u32Width and height of the square micro-blocks used by tiled encoding.
no_data_value: Option<f64>Optional per-sample no-data sentinel for rasters whose depth is greater than one.
Implementations
Sourceimpl EncodeOptions
impl EncodeOptions
Sourcepub const fn with_max_z_error(self, max_z_error: f64) -> Self
pub const fn with_max_z_error(self, max_z_error: f64) -> Self
Sets the requested maximum absolute reconstruction error.
Sourcepub const fn with_micro_block_size(self, micro_block_size: u32) -> Self
pub const fn with_micro_block_size(self, micro_block_size: u32) -> Self
Sets the square micro-block size. Supported values are 2 through 32.
Sourcepub const fn with_no_data_value(self, no_data_value: f64) -> Self
pub const fn with_no_data_value(self, no_data_value: f64) -> Self
Sets the no-data sentinel used by multidimensional rasters.
Sourcepub const fn without_no_data_value(self) -> Self
pub const fn without_no_data_value(self) -> Self
Removes a previously configured no-data sentinel.